closeProject()
newProject( "beam", 1000 )
setModelAnalysisAspects( [ "STRUCT" ] )
setModelDimension( "2D" )

setUnit( "LENGTH", "MM" )

# Geometrical properties for the beam
HEIGHT=400
WIDTH=200
LENGTH=5400 # Physical length + 400 [mm]
LOADPOSITION=LENGTH/2
SUPPORT1=200
SUPPORT2=LENGTH-200
PLATEWIDTH=150
PLATEHEIGHT=35
XCOORD=[0,SUPPORT1-PLATEWIDTH/2,SUPPORT1+PLATEWIDTH/2,LOADPOSITION-PLATEWIDTH/2,LOADPOSITION+PLATEWIDTH/2,SUPPORT2-PLATEWIDTH/2,SUPPORT2+PLATEWIDTH/2, LENGTH ]
XCOORD.sort()
SUPPORTPLATE1COORD=[SUPPORT1-PLATEWIDTH/2,SUPPORT1,SUPPORT1+PLATEWIDTH/2]
SUPPORTPLATE2COORD=[SUPPORT2-PLATEWIDTH/2,SUPPORT2,SUPPORT2+PLATEWIDTH/2]
LOADPLATECOORD=[LOADPOSITION-PLATEWIDTH/2,LOADPOSITION,LOADPOSITION+PLATEWIDTH/2]
SUPPORTPLATE1COORD.sort()
SUPPORTPLATE2COORD.sort()
LOADPLATECOORD.sort()

#MATERIAL PROPERTIES

#Concrete material properties
fcsitu=29.1997
fcksitu=fcsitu-6
fctsitu=0.3*fcksitu**(2/3)
gf=73*fcsitu**0.18/1000
gc=250*gf
YOUNGSMOD = 21500*(fcsitu/10)**(1/3)
POISSONRATIO=0.15

#Reinforcement material properties
esu=0.075
ES=200000.0
fsy=560
esy=fsy/ES
fsu=fsy*1.25

f = open('Materialparameter.txt','w')
f.write("%2.4f \n%5.2f \n%3.4f \n%3.4f " % (fcsitu, YOUNGSMOD, fsy, fsu))
f.close()

#Reinforcement geometry and placement

As=0.005*(HEIGHT-50)*WIDTH
coverbot=50

# CREATE CONCRETE
SHAPELIST=[]
SHAPENUMBER=1
#createSheet("Sheet",[[XCOORD[0],0,0],[XCOORD[1],0,0],[XCOORD[1],HEIGHT,0],[XCOORD[0],HEIGHT,0]])
for i in range (0,(len(XCOORD)-1)):
	createSheet('SHEET{}'.format(SHAPENUMBER),[[XCOORD[i],0,0],[XCOORD[i+1],0,0],[XCOORD[i+1],HEIGHT,0],[XCOORD[i],HEIGHT,0]])
	SHAPELIST.append('SHEET{}'.format(SHAPENUMBER))
	SHAPENUMBER=SHAPENUMBER+1

#Create plates 
PLATENUMBER=1
PLATELIST=[]
for j in range(0,(len(SUPPORTPLATE1COORD)-1)):
	createSheet('SUPLATE{}'.format(PLATENUMBER),[[SUPPORTPLATE1COORD[j],-PLATEHEIGHT,0],[SUPPORTPLATE1COORD[j+1],-PLATEHEIGHT,0],[SUPPORTPLATE1COORD[j+1],0,0],[SUPPORTPLATE1COORD[j],0,0]])
	PLATELIST.append('SUPLATE{}'.format(PLATENUMBER))
	
	PLATENUMBER=PLATENUMBER+1

for j in range(0,(len(SUPPORTPLATE2COORD)-1)):
	createSheet('SUPLATE{}'.format(PLATENUMBER),[[SUPPORTPLATE2COORD[j],-PLATEHEIGHT,0],[SUPPORTPLATE2COORD[j+1],-PLATEHEIGHT,0],[SUPPORTPLATE2COORD[j+1],0,0],[SUPPORTPLATE2COORD[j],-0,0]])
	PLATELIST.append('SUPLATE{}'.format(PLATENUMBER))
	PLATENUMBER=PLATENUMBER+1

LOADNUMBER=1
for j in range(0,(len(LOADPLATECOORD)-1)):
	createSheet('LOPLATE{}'.format(LOADNUMBER),[[LOADPLATECOORD[j],HEIGHT,0],[LOADPLATECOORD[j+1],HEIGHT,0],[LOADPLATECOORD[j+1],HEIGHT+PLATEHEIGHT,0],[LOADPLATECOORD[j],HEIGHT+PLATEHEIGHT,0]])
	PLATELIST.append('LOPLATE{}'.format(LOADNUMBER))
	LOADNUMBER=LOADNUMBER+1


 # CREATE REINFORCEMENT
ASSTIRR=[]
ASLONG=[]
PB11=[0,coverbot,0]
PB12=[LENGTH,coverbot,0]
createLine("REIBOT",PB11,PB12)
ASLONG.append("REIBOT")

# ADD CONCRETE MATERIAL PROPERTIES
addElementData( "Concrete" )
setParameter( DATA, "Concrete", "INTEGR", "REGULA" )
setParameter( DATA, "Concrete", "NUMINT", [ "GAUSS" ] )
addMaterial( "Concrete", "CONCR", "TSCR", [] )

setParameter( MATERIAL, "Concrete", "LINEAR/ELASTI/YOUNG", YOUNGSMOD )
setParameter( MATERIAL, "Concrete", "LINEAR/ELASTI/POISON", POISSONRATIO )

setParameter( MATERIAL, "Concrete", "MODTYP/TOTCRK", "ROTATE" )
setParameter( MATERIAL, "Concrete", "TENSIL/TENCRV", "EXPONE" )
setParameter( MATERIAL, "Concrete", "TENSIL/REDUCT/REDCRV", "VC1993" )
setParameter( MATERIAL, "Concrete", "TENSIL/REDUCT/REDMIN", 0.6 )
setParameter( MATERIAL, "Concrete", "TENSIL/POISRE/POIRED", "DAMAGE" )
setParameter( MATERIAL, "Concrete", "COMPRS/COMCRV", "PARABO" )
setParameter( MATERIAL, "Concrete", "COMPRS/CONFIN/CNFCRV", "VECCHI" )

setParameter( MATERIAL, "Concrete", "TENSIL/TENSTR", fctsitu )
setParameter( MATERIAL, "Concrete", "TENSIL/GF1", gf )
setParameter( MATERIAL, "Concrete", "COMPRS/COMSTR", fcsitu )
setParameter( MATERIAL, "Concrete", "COMPRS/GC", gc )

addGeometry( "Concrete", "SHEET", "MEMBRA", [] )
setParameter( GEOMET, "Concrete", "THICK", WIDTH )

assignMaterial( "Concrete", "SHAPE", SHAPELIST )
assignGeometry( "Concrete", "SHAPE", SHAPELIST )
assignElementData( "Concrete", "SHAPE", SHAPELIST )
# ADD REINFORCEMENT PROPERTIES
REI=ASLONG+ASSTIRR
for i in range (0,len(REI)):
	materialname=REI[i]
	addMaterial( materialname, "MCSTEL", "TRESCA", [] )
	setParameter( MATERIAL, materialname, "LINEAR/ELASTI/YOUNG", ES )
	setParameter( MATERIAL, materialname, "TREPLA/YIELD", "VMISES" )
	setParameter( MATERIAL, materialname, "TREPLA/TRESSH", "EPSSIG" )
	setParameter( MATERIAL, materialname, "TREPLA/HARDEN", "STRAIN" )
	setParameter( MATERIAL, materialname, "TREPLA/EPSSIG", [ 0,0, esy, fsy, esu, fsu] )
	addGeometry( materialname, "RELINE", "REBAR", [] )
	setParameter( GEOMET, materialname, "CROSSE", As )
	

for i in range (0,len(REI)):
	assignMaterial( REI[i], "SHAPE", ASLONG)
	assignGeometry( REI[i], "SHAPE", ASLONG)

# ADD PLATE PROPERTIES
addElementData( "Plate" )
setParameter( DATA, "Plate", "INTEGR", "REGULA" )
setParameter( DATA, "Plate", "NUMINT", [ "GAUSS" ] )
addMaterial( "Plate", "MCSTEL", "ISOTRO", [] )
setParameter( MATERIAL, "Plate", "LINEAR/ELASTI/YOUNG", 200000 )
setParameter( MATERIAL, "Plate", "LINEAR/ELASTI/POISON", 0.3 )
addGeometry( "Plate", "SHEET", "MEMBRA", [] )
setParameter( GEOMET, "Plate", "THICK", WIDTH )

assignMaterial( "Plate", "SHAPE", PLATELIST)
assignGeometry( "Plate", "SHAPE", PLATELIST)
assignElementData( "Plate", "SHAPE", PLATELIST )

#DEFINE INTERFACE ELEMENTS
addElementData( "Interface" )
setParameter( DATA, "Interface", "NUMINT", [ "LOBATT" ] )
setParameter( DATA, "Interface", "INTEGR", "REGULA" )

addMaterial( "Interface", "INTERF", "ELASTI", [] )
setParameter( MATERIAL, "Interface", "LINEAR/IFTYP", "LIN2D" )
setParameter( MATERIAL, "Interface", "LINEAR/ELAS2/DSNY", 36300 )
setParameter( MATERIAL, "Interface", "LINEAR/ELAS2/DSSX", 3.63e-08 )

addGeometry( "Interface", "LINE", "STRLIF", [] )
setParameter( GEOMET, "Interface", "THICK", WIDTH )

setInterfaceContactAspects( SHAPEEDGE, "SHEET2", [[ 200, 0, 0 ]], "Interface" )
setElementClassType( SHAPEEDGE, "SHEET2", [[ 200, 0, 0 ]], "STRLIF" )
assignGeometry( "Interface", SHAPEEDGE, "SHEET2", [[ 200, 0, 0 ]] )
setInterfaceContactAspects( SHAPEEDGE, "SHEET4", [[ 2700, 400, 0 ]], "Interface" )
setElementClassType( SHAPEEDGE, "SHEET4", [[ 2700, 400, 0 ]], "STRLIF" )
assignGeometry( "Interface", SHAPEEDGE, "SHEET4", [[ 2700, 400, 0 ]] )
setInterfaceContactAspects( SHAPEEDGE, "SHEET6", [[ 5200, 0, 0 ]], "Interface" )
setElementClassType( SHAPEEDGE, "SHEET6", [[ 5200, 0, 0 ]], "STRLIF" )
assignGeometry( "Interface", SHAPEEDGE, "SHEET6", [[ 5200, 0, 0 ]] )


#LOAD
addSet( GEOMETRYLOADSET, "Geometry load set 2" )
createPointLoad( "Load", "Geometry load set 2" )
setParameter( GEOMETRYLOAD, "Load", "FORCE/VALUE", -100000 )
setParameter( GEOMETRYLOAD, "Load", "FORCE/DIRECT", 2 )
attach( GEOMETRYLOAD, "Load", "LOPLATE1", [[ LOADPOSITION, HEIGHT+PLATEHEIGHT, 0 ]] )

# SUPPORTS

addSet( SUPPORTSET, "Support set 1" )
addSet( GEOMETRYSUPPORTSET, "Geometry support set 1" )
createPointSupport( "LEFTSUPPORT", "Geometry support set 1" )
setParameter( GEOMETRYSUPPORT, "LEFTSUPPORT", "AXES", [ 1, 2 ] )
setParameter( GEOMETRYSUPPORT, "LEFTSUPPORT", "TRANSL", [ 1, 1, 0 ] )
setParameter( GEOMETRYSUPPORT, "LEFTSUPPORT", "ROTATI", [ 0, 0, 0 ] )

createPointSupport( "RIGHTSUPPORT", "Geometry support set 1" )
setParameter( GEOMETRYSUPPORT, "RIGHTSUPPORT", "AXES", [ 1, 2 ] )
setParameter( GEOMETRYSUPPORT, "RIGHTSUPPORT", "TRANSL", [ 0, 1, 0] )
setParameter( GEOMETRYSUPPORT, "RIGHTSUPPORT", "ROTATI", [ 0, 0, 0 ] )

attach( GEOMETRYSUPPORT, "LEFTSUPPORT", "SUPLATE1", [[ SUPPORT1, -PLATEHEIGHT, 0]] )
attach( GEOMETRYSUPPORT, "RIGHTSUPPORT", "SUPLATE3", [[ SUPPORT2, -PLATEHEIGHT, 0]] )

# MESH
ELEMENTSIZE =HEIGHT/6

setElementSize( SHAPELIST, ELEMENTSIZE )
setElementSize( PLATELIST, ELEMENTSIZE )
setElementClassType( SHAPELIST, "MEMBRA" )
setElementClassType( PLATELIST, "MEMBRA" )
setDefaultMeshOrder("QUADRATIC")
setDefaultMesherType( "HEXQUAD" )
setReinforcementAspects (REI)

generateMesh(shapes())


#Nonlinear analysis
analysis = "Nonlinear analysis"
command  = "Structural nonlinear"
addAnalysis( analysis )
addAnalysisCommand( analysis, "NONLIN", command )
setAnalysisCommandDetail( analysis, command, "MODEL", True )
setAnalysisCommandDetail( analysis, command, "MODEL/EVALUA", True )
addAnalysisCommandDetail( analysis, command, "MODEL/EVALUA/CHECK" )
setAnalysisCommandDetail( analysis, command, "MODEL/EVALUA/CHECK", False )
setAnalysisCommandDetail( analysis, command, "MODEL/EVALUA/AVERAG", True )
setAnalysisCommandDetail( analysis, command, "MODEL/EVALUA/AVERAG/ANGLE", 0.3490658504 )
setAnalysisCommandDetail( analysis, command, "MODEL/EVALUA/REINFO", True )
setAnalysisCommandDetail( analysis, command, "MODEL/EVALUA/REINFO/INTERF", False )
setAnalysisCommandDetail( analysis, command, "MODEL/EVALUA/REINFO/GRID/FULLEL", False )
setAnalysisCommandDetail( analysis, command, "MODEL/EVALUA/COMPOS", True )
setAnalysisCommandDetail( analysis, command, "MODEL/ASSEMB", True )
setAnalysisCommandDetail( analysis, command, "MODEL/ASSEMB/TOLERA", 1e-06 )
setAnalysisCommandDetail( analysis, command, "MODEL/MATRIX", True )
setAnalysisCommandDetail( analysis, command, "MODEL/LOADS", True )

setAnalysisCommandDetail( analysis, command, "TYPE", True )
setAnalysisCommandDetail( analysis, command, "TYPE/PHYSIC", True )
setAnalysisCommandDetail( analysis, command, "TYPE/PHYSIC/PLASTI", True )
setAnalysisCommandDetail( analysis, command, "TYPE/PHYSIC/PLASTI/MITERA", 25 )
setAnalysisCommandDetail( analysis, command, "TYPE/PHYSIC/PLASTI/TOLERA", 0.0001 )
setAnalysisCommandDetail( analysis, command, "TYPE/PHYSIC/PLASTI/TANGEN", "FIRST" )
setAnalysisCommandDetail( analysis, command, "TYPE/PHYSIC/PLASTI/SUBSTP", 0.01 )
setAnalysisCommandDetail( analysis, command, "TYPE/PHYSIC/CREEP", True )
setAnalysisCommandDetail( analysis, command, "TYPE/PHYSIC/CREEP/MITERA", 1 )
setAnalysisCommandDetail( analysis, command, "TYPE/PHYSIC/CREEP/TOLERA", 0.0001 )
setAnalysisCommandDetail( analysis, command, "TYPE/PHYSIC/CREEP/TANGEN", "ZERO" )
setAnalysisCommandDetail( analysis, command, "TYPE/PHYSIC/CRACKI", True )
setAnalysisCommandDetail( analysis, command, "TYPE/PHYSIC/CRACKI/TOLDIR", 60 )
setAnalysisCommandDetail( analysis, command, "TYPE/PHYSIC/CRACKI/TOLTCO", 0.001 )
setAnalysisCommandDetail( analysis, command, "TYPE/PHYSIC/CRACKI/TANGEN", "SECANT" )
setAnalysisCommandDetail( analysis, command, "TYPE/PHYSIC/TOTCRK", True )
setAnalysisCommandDetail( analysis, command, "TYPE/PHYSIC/TOTCRK/TANGEN", "SECANT" )
setAnalysisCommandDetail( analysis, command, "TYPE/PHYSIC/ELASTI", True )
setAnalysisCommandDetail( analysis, command, "TYPE/PHYSIC/HYPERE", True )
setAnalysisCommandDetail( analysis, command, "TYPE/PHYSIC/VISCOE", True )
setAnalysisCommandDetail( analysis, command, "TYPE/PHYSIC/VISCOP", True )
setAnalysisCommandDetail( analysis, command, "TYPE/PHYSIC/INTERF", True )
setAnalysisCommandDetail( analysis, command, "TYPE/PHYSIC/SHRINK", True )
setAnalysisCommandDetail( analysis, command, "TYPE/PHYSIC/TEMPER", True )
setAnalysisCommandDetail( analysis, command, "TYPE/PHYSIC/CONCEN", True )
setAnalysisCommandDetail( analysis, command, "TYPE/PHYSIC/MATURI", True )
setAnalysisCommandDetail( analysis, command, "TYPE/PHYSIC/CORROS", True ) 
addAnalysisCommandDetail( analysis, command, "TYPE/GEOMET" )
setAnalysisCommandDetail( analysis, command, "TYPE/GEOMET", False )
addAnalysisCommandDetail( analysis, command, "TYPE/TRANSI" )
setAnalysisCommandDetail( analysis, command, "TYPE/TRANSI", False )
setAnalysisCommandDetail( analysis, command, "TYPE/LINSTR", False )
setAnalysisCommandDetail( analysis, command, "TYPE/RETSTR", False )
 
  
setAnalysisCommandDetail( analysis, command, "EXECUT(1)/LOAD", True )
setAnalysisCommandDetail( analysis, command, "EXECUT(1)/LOAD/LOADNR", 1 )
setAnalysisCommandDetail( analysis, command, "EXECUT(1)/LOAD/STEPS/EXPLIC/SIZES", "0.1(100)" )
addAnalysisCommandDetail( analysis, command,  "EXECUT(1)/LOAD/STEPS/EXPLIC/ARCLEN" )
setAnalysisCommandDetail( analysis, command,  "EXECUT(1)/LOAD/STEPS/EXPLIC/ARCLEN", True )
setAnalysisCommandDetail( analysis, command, "EXECUT(1)/LOAD/STEPS/EXPLIC/ARCLEN/METHOD", "UPDATE" )
setAnalysisCommandDetail( analysis, command, "EXECUT(1)/LOAD/STEPS/EXPLIC/ARCLEN/CONTRO", "REGULA" )
setAnalysisCommandDetail( analysis, command, "EXECUT(1)/LOAD/STEPS/EXPLIC/ARCLEN/UNLOAD", "SIGN" )
addAnalysisCommandDetail( analysis, command, "EXECUT(1)/LOAD/STEPS/EXPLIC/ARCLEN/AUTARC" )
setAnalysisCommandDetail( analysis, command, "EXECUT(1)/LOAD/STEPS/EXPLIC/ARCLEN/AUTARC", False )
  
setAnalysisCommandDetail( analysis, command, "EXECUT(1)/ITERAT/MAXITE", 100)
setAnalysisCommandDetail( analysis, command, "EXECUT(1)/ITERAT/METHOD/METNAM", "NEWTON" )
setAnalysisCommandDetail( analysis, command, "EXECUT(1)/ITERAT/METHOD/NEWTON/TYPNAM", "REGULA" )
setAnalysisCommandDetail( analysis, command, "EXECUT(1)/ITERAT/METHOD/NEWTON/START", "TANGEN" )
addAnalysisCommandDetail( analysis, command, "EXECUT(1)/ITERAT/LINESE" )
setAnalysisCommandDetail( analysis, command, "EXECUT(1)/ITERAT/LINESE", True )
setAnalysisCommandDetail( analysis, command, "EXECUT(1)/ITERAT/LINESE/ETAMIN", 0.1 )
setAnalysisCommandDetail( analysis, command, "EXECUT(1)/ITERAT/LINESE/ETAMAX", 1 )
setAnalysisCommandDetail( analysis, command, "EXECUT(1)/ITERAT/LINESE/MAXLS", 5 )
setAnalysisCommandDetail( analysis, command, "EXECUT(1)/ITERAT/LINESE/PSI", 0.8 )
setAnalysisCommandDetail( analysis, command, "EXECUT(1)/ITERAT/LINESE/DETA", 0.1 )
setAnalysisCommandDetail( analysis, command, "EXECUT(1)/ITERAT/CONTIN", False )
setAnalysisCommandDetail( analysis, command, "EXECUT(1)/ITERAT/CONVER/SIMULT", False )
addAnalysisCommandDetail( analysis, command, "EXECUT(1)/ITERAT/CONVER/ENERGY" )
setAnalysisCommandDetail( analysis, command, "EXECUT(1)/ITERAT/CONVER/ENERGY", True )
setAnalysisCommandDetail( analysis, command, "EXECUT(1)/ITERAT/CONVER/ENERGY/TOLCON", 0.001 )
setAnalysisCommandDetail( analysis, command, "EXECUT(1)/ITERAT/CONVER/ENERGY/REFERE", "NEWREF" )
setAnalysisCommandDetail( analysis, command, "EXECUT(1)/ITERAT/CONVER/ENERGY/TOLABT", 10000 )
setAnalysisCommandDetail( analysis, command, "EXECUT(1)/ITERAT/CONVER/ENERGY/NOCONV", "CONTIN" )
setAnalysisCommandDetail( analysis, command, "EXECUT(1)/ITERAT/CONVER/DISPLA", False )
setAnalysisCommandDetail( analysis, command, "EXECUT(1)/ITERAT/CONVER/FORCE", True )
setAnalysisCommandDetail( analysis, command, "EXECUT(1)/ITERAT/CONVER/FORCE/TOLCON", 0.01 )
setAnalysisCommandDetail( analysis, command, "EXECUT(1)/ITERAT/CONVER/FORCE/TOLABT", 10000 )
setAnalysisCommandDetail( analysis, command, "EXECUT(1)/ITERAT/CONVER/FORCE/REFERE", "NEWREF" )
setAnalysisCommandDetail( analysis, command, "EXECUT(1)/ITERAT/CONVER/FORCE/NOCONV", "CONTIN" )
setAnalysisCommandDetail( analysis, command, "EXECUT(1)/ITERAT/CONVER/RESIDU", False )

setAnalysisCommandDetail( analysis, command, "EXECUT(1)/SOLVE", True )
setAnalysisCommandDetail( analysis, command, "EXECUT(1)/SOLVE/TYPE", "CHOLES" )
setAnalysisCommandDetail( analysis, command, "EXECUT(1)/SOLVE/TOLERA", 1e-08 )
addAnalysisCommandDetail( analysis, command, "EXECUT(1)/SOLVE/CHOLES/SUBSTR" )
setAnalysisCommandDetail( analysis, command, "EXECUT(1)/SOLVE/CHOLES/SUBSTR", True )

setAnalysisCommandDetail( analysis, command, "EXECUT(1)/LOGGIN", True )
setAnalysisCommandDetail( analysis, command, "EXECUT(1)/LOGGIN/PLASTI", True )
setAnalysisCommandDetail( analysis, command, "EXECUT(1)/LOGGIN/CRACKI", True )
setAnalysisCommandDetail( analysis, command, "EXECUT(1)/LOGGIN/REACTI", True )
setAnalysisCommandDetail( analysis, command, "EXECUT(1)/LOGGIN/REPORT/AMOUNT", "BRIEF" )
setAnalysisCommandDetail( analysis, command, "EXECUT(1)/LOGGIN/REPORT/TERMIN", "STEP" )
   
setAnalysisCommandDetail( analysis, command, "SOLVE", True )   
setAnalysisCommandDetail( analysis, command, "SOLVE/TYPE", "CHOLES" )
setAnalysisCommandDetail( analysis, command, "SOLVE/TOLERA", 1e-08 )
setAnalysisCommandDetail( analysis, command, "SOLVE/CHOLES/SUBSTR", True )
setAnalysisCommandDetail( analysis, command, "SOLVE/CHOLES/SUBSTR/STATUS", "AUTOMA" )
setAnalysisCommandDetail( analysis, command, "SOLVE/CHOLES/SUBSTR/NUMSUB", 1 )
setAnalysisCommandDetail( analysis, command, "SOLVE/CHOLES/FACTOR", True )
 


#MUST MANUALLY ENTER ELEMENTS
joinElements( "Crush", [204, 249, 250, 462 ] )
addElementGroup( "Crush", [ "Crush" ] )
ELECRUSH=elementsInGroup("Crush")

joinElements( "REITEN", [ 29, 239, 240, 287 ] )
addElementGroup("REITEN",["REITEN"])
REITEN=elementsInGroup("REITEN")

DISPCOORD = [LOADPOSITION, 0,0 ]
DISPNODE = findNearestNodes([DISPCOORD])
FORCENODE1 = findNearestNodes([[SUPPORT1,-PLATEHEIGHT,0]])
FORCENODE2 = findNearestNodes([[SUPPORT2,-PLATEHEIGHT,0]])
FORCENODES = [FORCENODE1[0],FORCENODE2[0]]
ALLNODES=[FORCENODES[0],FORCENODES[1], DISPNODE[0]]
addNodeGroup( "Force-disp", ALLNODES )

setAnalysisCommandDetail( analysis, command, "OUTPUT(1)", True )
setAnalysisCommandDetail( analysis, command, "OUTPUT(1)/DEVICE", "TABULA" )
addAnalysisCommandDetail( analysis, command, "OUTPUT(1)/APPEND" )
setAnalysisCommandDetail( analysis, command, "OUTPUT(1)/APPEND", False )
addAnalysisCommandDetail( analysis, command, "OUTPUT(1)/LAYOUT/COMBIN" )
setAnalysisCommandDetail( analysis, command, "OUTPUT(1)/LAYOUT/COMBIN", False )
setAnalysisCommandDetail( analysis, command, "OUTPUT(1)/LAYOUT/LINPAG", 0 )
setAnalysisCommandDetail( analysis, command, "OUTPUT(1)/LAYOUT/COLLIN", 130 )
setAnalysisCommandDetail( analysis, command, "OUTPUT(1)/LAYOUT/DIGITS/RESULT", 4 )
setAnalysisCommandDetail( analysis, command, "OUTPUT(1)/LAYOUT/DIGITS/COORD", 4 )
setAnalysisCommandDetail( analysis, command, "OUTPUT(1)/LAYOUT/DIGITS/AXES", 3 )
setAnalysisCommandDetail( analysis, command, "OUTPUT(1)/SELECT/STEPS/RNGNRS", "ALL" )
addAnalysisCommandDetail( analysis, command, "OUTPUT(1)/SELECT/STEPS/MIN" )
setAnalysisCommandDetail( analysis, command, "OUTPUT(1)/SELECT/STEPS/MIN", False )
addAnalysisCommandDetail( analysis, command, "OUTPUT(1)/SELECT/STEPS/MAX" )
setAnalysisCommandDetail( analysis, command, "OUTPUT(1)/SELECT/STEPS/MAX", False )
addAnalysisCommandDetail( analysis, command, "OUTPUT(1)/FILE" )
setAnalysisCommandDetail( analysis, command, "OUTPUT(1)/FILE", "Output" )
setAnalysisCommandDetail( analysis, command, "OUTPUT(1)/SELECT/ELEMEN(1)/NODES/RNGNRS", "ALL" )
setAnalysisCommandDetail( analysis, command, "OUTPUT(1)/SELECT/ELEMEN(1)/INTPNT/RNGNRS", "ALL" )
setAnalysisCommandDetail( analysis, command, "OUTPUT(1)/SELECT/ELEMEN(1)/STRPNT/RNGNRS", "ALL" )
setAnalysisCommandDetail( analysis, command, "OUTPUT(1)/SELECT/ELEMEN(1)/CROSSE/RNGNRS", "ALL" )
addAnalysisCommandDetail( analysis, command, "OUTPUT(1)/SELECT/ELEMEN(1)/REAXES" )
setAnalysisCommandDetail( analysis, command, "OUTPUT(1)/SELECT/ELEMEN(1)/REAXES", False )
setAnalysisCommandDetail( analysis, command, "OUTPUT(1)/SELTYP", "USER" )
setAnalysisCommandDetail( analysis, command, "OUTPUT(1)/SELECT/MODSEL", "USER" )
setAnalysisCommandDetail( analysis, command, "OUTPUT(1)/SELECT/ELEMEN(1)/RNGNRS", "\"Crush\"" )
addAnalysisCommandDetail( analysis, command, "OUTPUT(1)/USER/STRAIN(1)/TOTAL/GREEN/PRINCI" )
setAnalysisCommandDetail( analysis, command, "OUTPUT(1)/USER/STRAIN(1)/TOTAL/GREEN/PRINCI/LOCATI", "INTPNT" )
setAnalysisCommandDetail( analysis, command, "OUTPUT(1)/SELECT/NODES(1)/RNGNRS", "\"Force-disp\"" )
setAnalysisCommandDetail( analysis, command, "OUTPUT(1)/SELECT/REINFO(1)/RNGNRS", "ALL" )
#NODE MOST BE MANUALLY PUT IN FOR DIFFERENT BEAMS
setAnalysisCommandDetail( analysis, command, "OUTPUT(1)/SELECT/REINFO(1)/ELEMEN/RNGNRS", "29 239 240 287" )
setAnalysisCommandDetail( analysis, command, "OUTPUT(1)/SELECT/REINFO(1)/INTPNT/RNGNRS", "ALL" )
addAnalysisCommandDetail( analysis, command, "OUTPUT(1)/USER/STRESS(1)/TOTAL/CAUCHY/GLOBAL" )
addAnalysisCommandDetail( analysis, command, "OUTPUT(1)/USER/DISPLA(1)/TOTAL/TRANSL/GLOBAL" )
addAnalysisCommandDetail( analysis, command, "OUTPUT(1)/USER/FORCE(1)/REACTI/TRANSL/GLOBAL" )
setAnalysisCommandDetail( analysis, command, "OUTPUT(1)/LAYOUT/LINPAG", 0 )
setAnalysisCommandDetail( analysis, command, "OUTPUT(1)/USER/DISPLA(1)/TOTAL/TRANSL/GLOBAL/COMP", [ "Y" ] )
setAnalysisCommandDetail( analysis, command, "OUTPUT(1)/USER/FORCE(1)/REACTI/TRANSL/GLOBAL/COMP", [ "Y" ] )
setAnalysisCommandDetail( analysis, command, "OUTPUT(1)/USER/STRAIN(1)/TOTAL/GREEN/PRINCI/COMP", [ "1", "2", "3" ] )
setAnalysisCommandDetail( analysis, command, "OUTPUT(1)/USER/STRESS(1)/TOTAL/CAUCHY/GLOBAL/COMP", [ "XX" ] )
setAnalysisCommandDetail( analysis, command, "OUTPUT(1)/USER/STRESS(1)/TOTAL/CAUCHY/GLOBAL/LOCATI", "INTPNT" )
exportModel(analysis)
runSolver(analysis)